==> kari-0.23.tar.gz: kari-0.23/alyson/alyson.c <==
/* YAWN, Yet Another Web Navigator */
/* Copyright (C) 1998, James Troup <jjtroup@comp.brad.ac.uk>
 *                     Lee Willis <lwillis@comp.brad.ac.uk> */

/* This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <string.h>
#include <gtk/gtk.h>
#include "utils.h"
#include "neve.h"
#include "lisa.h"
#include "smg.h"
#include "parser.h"
#include "cole.h"
#include "init.h"
#include "menu.h"
#include "text.h"
#include "urlentry.h"
#include "alyson.h"

/* The following causes "common.h" to produce definitions of all the global
   variables, rather than just "extern" declarations of them. */
#define GLOBAL
#include "globals.h"

BrowserWindow *cole;

/*****************************************************************************
 * function  : main
 * arguments : argc and argv
 * results   : 
 * purpose   : startup YAWN.
 * caveats   : You may be disappointed by YAWN.
 ***************************************************************************** */

int
main (int argc, char **argv)
{

  GtkWidget *tiffani;
  GtkWidget *menubar;

  char *filename, *full_path;
  int optind;

  program_name = argv[0];

  gtk_init (&argc, &argv);
  optind = parse_opt (argc, argv);

  cole = g_malloc (sizeof (BrowserWindow));
  cole->main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (cole->main_window, "text window");

  gtk_signal_connect (GTK_OBJECT (cole->main_window), "destroy",
		      (GtkSignalFunc) destroy_window,
		      &cole->main_window);
  gtk_signal_connect (GTK_OBJECT (cole->main_window), "delete_event",
		      (GtkSignalFunc) destroy_window,
		      &cole->main_window);

  gtk_window_set_title (GTK_WINDOW (cole->main_window), "YAWN");
  gtk_container_border_width (GTK_CONTAINER (cole->main_window), 10);

  tiffani = gtk_vbox_new (FALSE, 0);
  menubar = menu_init (cole);
  gtk_box_pack_start (GTK_BOX (tiffani), menubar, FALSE, FALSE, 0);
  gtk_widget_show (menubar);

  cole->url_entry = urlentry_init ();
  gtk_box_pack_start (GTK_BOX (tiffani), cole->url_entry, TRUE, TRUE, 0);
  gtk_widget_show (cole->url_entry);

  gtk_container_add (GTK_CONTAINER (cole->main_window), tiffani);
  gtk_widget_show (tiffani);

  gtk_window_add_accelerator_table (GTK_WINDOW (cole->main_window),
				    cole->accelerator_table);

  text_init (cole, tiffani);

  /* This entire section sucks, but it needs to be done now, so we can
   * set up the URL entry box to point at the right place. */

  /* FIXME: this sucks, but will do for now. */
  filename = xmalloc (4096);
  GTK_LISA (cole->lisa)->current_path = xmalloc (4096);
  full_path = xmalloc (8192);

  if (optind != argc)
    {
      /* FIXME: hairy code to handle command line passed URLs, should
       * be tidied up and abstracted somewhere. */

      char *temp;
      int i;

      debug (debug_alyson, "Would use %s", argv[optind]);
      if (argv[optind][0] != '/')
	{
	  getcwd (filename, 1024);
	  temp = filename + strlen (filename);
	  temp[0] = '/';
	  temp++;
	}
      else
	temp = filename;
      strcpy (temp, argv[optind]);
      debug (debug_alyson, "using %s", filename);

      i = strlen (filename);

      while (filename[i] != '/')
	i--;
      i++;

      temp = filename + i;
      debug (debug_alyson, "temp is %s", temp);

      strncpy (GTK_LISA (cole->lisa)->current_path, filename, i);
      strcpy (filename, temp);

    }
  else
    {
      strcpy (filename, "index.html");
      strcpy (GTK_LISA (cole->lisa)->current_path, "/home/yawn/examples/");
    }
  
  sprintf (full_path, "%s%s", GTK_LISA (cole->lisa)->current_path, filename);
  urlentry_update (cole->url_entry, full_path);

  gtk_widget_show (cole->main_window);
  gtk_window_set_title (GTK_WINDOW (cole->main_window), "foodebarfoodebazbat");
  do_doc (GTK_LISA (cole->lisa), filename);

  gtk_main ();

  return 0;

}

/*****************************************************************************
 * function  : do_doc
 * arguments : lisa pointer and a file name
 * results   : 
 * purpose   : fetches a document, and passes it to the parser.
 * caveats   : 
 ***************************************************************************** */

void
do_doc (GtkLisa * lisa, const char *filename)
{

  char *buffer_p;

  debug (debug_warn, "doing doc %s", filename);

  if (request_doc (&lisa->current_path, filename, &buffer_p) == 0)
    {
      parse_html (buffer_p, lisa);
      free (buffer_p);
    }
  else
    error ("do_doc: Couldn't get file \"%s\".", filename);
}

/*****************************************************************************
 * function  : destroy_window
 * arguments : 
 * results   : 
 * purpose   : die.
 * caveats   : 
 ***************************************************************************** */

void
destroy_window (void)
{
  gtk_main_quit ();
}

/* This is a sucky procedure, with one goal; get round the fact that
 * the URL entry box has no idea which SMG it's tied to */

BrowserWindow *
help_me_bob (void)
{
  return cole;
}

==> kari-0.24.tar.gz: kari-0.24/alyson/alyson.c <==
/* YAWN, Yet Another Web Navigator */
/* Copyright (C) 1998, James Troup <jjtroup@comp.brad.ac.uk>
 *                     Lee Willis <lwillis@comp.brad.ac.uk> */

/* This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <string.h>
#include <gtk/gtk.h>
#include "utils.h"
#include "neve.h"
#include "lisa.h"
#include "smg.h"
#include "parser.h"
#include "cole.h"
#include "init.h"
#include "menu.h"
#include "text.h"
#include "urlentry.h"
#include "alyson.h"

/* The following causes "common.h" to produce definitions of all the global
   variables, rather than just "extern" declarations of them. */
#define GLOBAL
#include "globals.h"

BrowserWindow *paula;

/*****************************************************************************
 * function  : main
 * arguments : argc and argv
 * results   : 
 * purpose   : startup YAWN.
 * caveats   : You may be disappointed by YAWN.
 ***************************************************************************** */

int
main (int argc, char **argv)
{

  GtkWidget *tiffani;
  GtkWidget *menubar;

  char *filename, *full_path;
  int optind;

  program_name = argv[0];

  gtk_init (&argc, &argv);
  optind = parse_opt (argc, argv);

  paula = xmalloc (sizeof (BrowserWindow));

  paula->title = xmalloc (strlen ("YAWN: you suck") + 1);
  strcpy (paula->title, "YAWN: you suck");

  paula->main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (paula->main_window, "text window");

  gtk_signal_connect (GTK_OBJECT (paula->main_window), "destroy",
		      (GtkSignalFunc) destroy_window,
		      &paula->main_window);
  gtk_signal_connect (GTK_OBJECT (paula->main_window), "delete_event",
		      (GtkSignalFunc) destroy_window,
		      &paula->main_window);

  gtk_container_border_width (GTK_CONTAINER (paula->main_window), 10);
  gtk_window_set_title (GTK_WINDOW (paula->main_window), "YAWN");
  gtk_widget_set_usize (paula->main_window, 800, 800);
  gtk_window_set_policy (GTK_WINDOW (paula->main_window), TRUE, TRUE, TRUE);

  tiffani = gtk_vbox_new (FALSE, 0);
  menubar = menu_init (paula);
  gtk_box_pack_start (GTK_BOX (tiffani), menubar, FALSE, FALSE, 0);
  gtk_widget_show (menubar);

  paula->url_entry = urlentry_init ();
  gtk_box_pack_start (GTK_BOX (tiffani), paula->url_entry, FALSE, FALSE, 0);
  gtk_widget_show (paula->url_entry);

  gtk_container_add (GTK_CONTAINER (paula->main_window), tiffani);
  gtk_widget_show (tiffani);

  gtk_window_add_accelerator_table (GTK_WINDOW (paula->main_window),
				    paula->accelerator_table);

  text_init (paula, tiffani);

  /* This entire section sucks, but it needs to be done now, so we can
   * set up the URL entry box to point at the right place. */

  /* FIXME: this sucks, but will do for now. */
  filename = xmalloc (4096);
  GTK_LISA (paula->lisa)->current_path = xmalloc (4096);
  full_path = xmalloc (8192);

  if (optind != argc)
    {
      /* FIXME: hairy code to handle command line passed URLs, should
       * be tidied up and abstracted somewhere. */

      char *temp;
      int i;

      debug (debug_alyson, "Would use %s", argv[optind]);
      if (argv[optind][0] != '/')
	{
	  getcwd (filename, 1024);
	  temp = filename + strlen (filename);
	  temp[0] = '/';
	  temp++;
	}
      else
	temp = filename;
      strcpy (temp, argv[optind]);
      debug (debug_alyson, "using %s", filename);

      i = strlen (filename);

      while (filename[i] != '/')
	i--;
      i++;

      temp = filename + i;
      debug (debug_alyson, "temp is %s", temp);

      strncpy (GTK_LISA (paula->lisa)->current_path, filename, i);
      strcpy (filename, temp);

    }
  else
    {
      strcpy (filename, "index.html");
      strcpy (GTK_LISA (paula->lisa)->current_path, "/home/yawn/examples/");
    }
  
  sprintf (full_path, "%s%s", GTK_LISA (paula->lisa)->current_path, filename);
  urlentry_update (paula->url_entry, full_path);

  gtk_widget_show (paula->main_window);
  do_doc (GTK_LISA (paula->lisa), filename);

  gtk_main ();

  return 0;

}

/*****************************************************************************
 * function  : do_doc
 * arguments : lisa pointer and a file name
 * results   : 
 * purpose   : fetches a document, and passes it to the parser.
 * caveats   : 
 ***************************************************************************** */

void
do_doc (GtkLisa * lisa, const char *filename)
{

  char *buffer_p;

  debug (debug_warn, "doing doc %s", filename);

  if (request_doc (&lisa->current_path, filename, &buffer_p) == 0)
    {
      parse_html (buffer_p, paula);
      free (buffer_p);
    }
  else
    error ("do_doc: Couldn't get file \"%s\".", filename);
}

/*****************************************************************************
 * function  : destroy_window
 * arguments : 
 * results   : 
 * purpose   : die.
 * caveats   : 
 ***************************************************************************** */

void
destroy_window (void)
{
  gtk_main_quit ();
}

/* This is a sucky procedure, with one goal; get round the fact that
 * the URL entry box has no idea which SMG it's tied to */

BrowserWindow *
help_me_bob (void)
{
  return paula;
}
